@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Author::PERLANCAR;
 
 our $DATE = '2014-12-14'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $VERSION = '0.32'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -17,7 +17,7 @@ sub configure {
     });
 
     $self->add_plugins(
-        'Rinci::AbstractFromName',
+        'Rinci::AbstractFromMeta',
         'PodnameFromFilename',
         'PERLANCAR::MetaResources',
         'CheckChangeLog',
@@ -54,7 +54,7 @@ Dist::Zilla::PluginBundle::Author::PERLANCAR - Dist::Zilla like PERLANCAR when y
 
 =head1 VERSION
 
-This document describes version 0.31 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2014-12-14.
+This document describes version 0.32 of Dist::Zilla::PluginBundle::Author::PERLANCAR (from Perl distribution Dist-Zilla-PluginBundle-Author-PERLANCAR), released on 2014-12-14.
 
 =head1 SYNOPSIS
 
